@@ -29,8 +29,10 @@ class Message(APIResource["Message"]):
 
     class Reference(TypedDict):
         name: str
+        description: Optional[str]
         url: Optional[str]
         sequenceNumber: int
+        originalIndex: Optional[list[int]]
         sourceId: str
         source: str
 
@@ -165,6 +167,12 @@ class Message(APIResource["Message"]):
         """
         Creates a new message object.
         """
+        # Clean up empty descriptions from references
+        if "references" in params and params["references"]:
+            for ref in params["references"]:
+                if "description" in ref and not ref["description"]:
+                    ref.pop("description")
+
         return cast(
             "Message",
             cls._static_request(
@@ -186,6 +194,12 @@ class Message(APIResource["Message"]):
         """
         Creates a new message object.
         """
+        # Clean up empty descriptions from references
+        if "references" in params and params["references"]:
+            for ref in params["references"]:
+                if "description" in ref and not ref["description"]:
+                    ref.pop("description")
+
         return cast(
             "Message",
             await cls._static_request_async(
@@ -208,6 +222,12 @@ class Message(APIResource["Message"]):
         """
         Updates an existing message object.
         """
+        # Clean up empty descriptions from references
+        if "references" in params and params["references"]:
+            for ref in params["references"]:
+                if "description" in ref and not ref["description"]:
+                    ref.pop("description")
+
         url = "%s/%s" % (cls.class_url(), quote_plus(id))
         return cast(
             "Message",
@@ -231,6 +251,12 @@ class Message(APIResource["Message"]):
         """
         Updates an existing message object.
         """
+        # Clean up empty descriptions from references
+        if "references" in params and params["references"]:
+            for ref in params["references"]:
+                if "description" in ref and not ref["description"]:
+                    ref.pop("description")
+
         url = "%s/%s" % (cls.class_url(), quote_plus(id))
         return cast(
             "Message",
@@ -324,6 +350,12 @@ class Message(APIResource["Message"]):
         """
         Creates a new message event object.
         """
+        # Clean up empty descriptions from references
+        if "references" in params and params["references"]:
+            for ref in params["references"]:
+                if "description" in ref and not ref["description"]:
+                    ref.pop("description")
+
         message_id = params.get("messageId")
         params.pop("messageId", None)
         return cast(
@@ -347,6 +379,12 @@ class Message(APIResource["Message"]):
         """
         Creates a new message event object.
         """
+        # Clean up empty descriptions from references
+        if "references" in params and params["references"]:
+            for ref in params["references"]:
+                if "description" in ref and not ref["description"]:
+                    ref.pop("description")
+
         message_id = params.get("messageId")
         params.pop("messageId", None)
         return cast(
