@@ -8,16 +8,18 @@ class MessageExecution(APIResource["MessageExecution"]):
     OBJECT_NAME: ClassVar[Literal["message_execution"]] = "message_execution"
     RESOURCE_URL = "/message-execution"
 
+    TypeLiteral = Literal["DEEP_RESEARCH"]
+    StatusLiteral = Literal["PENDING", "RUNNING", "COMPLETED", "FAILED"]
+    # Only COMPLETED and FAILED statuses are allowed for update
+    UpdateStatusLiteral = Literal["COMPLETED", "FAILED"]
+
     class CreateMessageExecutionParams(RequestOptions):
         """
         Parameters for creating a message execution.
         """
 
         messageId: str
-        chatId: str
-        type: Literal["DEEP_RESEARCH"]
-        secondsRemaining: NotRequired[int | None]
-        percentageCompleted: NotRequired[int | None]
+        type: "MessageExecution.TypeLiteral"
 
     class GetMessageExecutionParams(RequestOptions):
         """
@@ -32,18 +34,19 @@ class MessageExecution(APIResource["MessageExecution"]):
         """
 
         messageId: str
-        status: Literal["COMPLETED", "FAILED"]
+        status: NotRequired["MessageExecution.UpdateStatusLiteral | None"]
         secondsRemaining: NotRequired[int | None]
         percentageCompleted: NotRequired[int | None]
 
-    messageExecutionId: str | None
-    messageId: str | None
-    status: Literal["PENDING", "RUNNING", "COMPLETED", "FAILED"]
-    type: Literal["DEEP_RESEARCH"] = "DEEP_RESEARCH"
+    id: str
+    messageId: str
+    status: "MessageExecution.StatusLiteral"
+    type: "MessageExecution.TypeLiteral"
     secondsRemaining: int | None
     percentageCompleted: int | None
+    positionInQueue: int | None
     createdAt: str
-    updatedAt: str | None
+    updatedAt: str
 
     @classmethod
     def create(
